package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.28.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.28.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````9!@``#0```"<D0````(`!30`(``)
M`"@`&P`:``$``'!$AP``1(<``$2'```(````"`````0````$````!@```#0`
M```T````-````"`!```@`0``!`````0````#````5`$``%0!``!4`0``$P``
M`!,````$`````0````$```````````````````!0AP``4(<```4```````$`
M`0```(2-``"$C0$`A(T!`+P"``#4$@``!@```````0`"````C(T``(R-`0",
MC0$`*`$``"@!```&````!`````0```!H`0``:`$``&@!``!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DA(T`
M`(2-`0"$C0$`?`(``'P"```$`````0```"]L:6(O;&0M;&EN=7@N<V\N,P``
M!````!`````!````1TY5```````#`````@`````````$````%`````,```!'
M3E4`F<&LZ<Z[:YN[5504Q-G*F(:;XEH1````4`````@````(`````9`0!"5`
M!(`H@``!H(90@(`!```+*`2-.*`218H$"`A0````40```%4```!:````6P``
M`&(```!C````9````&8```!G`````````&D```!J````:P```&T`````````
M``````&O-.ANQ=\?ZM/O#L[>1RUK?YI\+L6;MG94/)0@_^0.N(WQ#M5DU'S9
M<5@<XD?&`:Q+X\"ZXY)\6.^7><+E/RSZH6Q@LP&+;VL)0]9GK\QF0D75[(D'
M<-,-%.*>VLWCGC-BV^T-.I<+?ZF<F[[:5QOAIP(*H^#[20``````````````
M````````````J!(````````#``L```````"0`0```````P`6`+<"````````
M`````!(```!E`P`````````````2````.0,`````````````(@```'X#````
M`````````!$```#W`P`````````````2````$0``````````````(````"H"
M`````````````!(````+`P`````````````2````5@,`````````````$@``
M`!$!`````````````!(```"6`P`````````````1````M```````````````
M$@```-("`````````````!(```"#`0`````````````2````O@(`````````
M````$@```(0``````````````!(````,`0`````````````2````V0(`````
M````````$@```)L"`````````````!(```!A`@`````````````2````.0(`
M````````````$@```'("`````````````!(```!_`@`````````````2````
M`0$`````````````$0```&<!`````````````!(```#C```````````````1
M````-0$`````````````$@```!(#`````````````!(````$`P``````````
M```1````&P,`````````````$@```,(``````````````!(```"Q`0``````
M```````2````(@(`````````````$@```)X!`````````````!(```#R`@``
M```````````2````"@(`````````````$@```*H!`````````````!(```!L
M`P`````````````2````0P$`````````````$@```"T``````````````"``
M``"4`@`````````````2````2P(`````````````$@```*D"````````````
M`!(```"\`0`````````````1````9```````````````$@```"@#````````
M`````!(```"3```````````````2````$0(`````````````$@```$@#````
M`````````!(```"?```````````````2````7`$`````````````$@```'D"
M`````````````!(```"P`@`````````````2````(@$`````````````$@``
M`%8``````````````!(````6`0`````````````2````DP$`````````````
M$@```,0"`````````````!(```#P```````````````2````C0(`````````
M````$@```%X#`````````````!(```"B`@`````````````2````=0$`````
M````````$@```',``````````````!(```!_`P`````````````A````+P,`
M````````````$@```-0``````````````!(```!3`0`````````````2````
M/```````````````(````(`#`````````````!$```#Z`@`````````````2
M````4`(`````````````$@```(<"`````````````!(````$`@``````````
M```2````YP(`````````````$@```%@"`````````````!(```#P`0``````
M```````2````%`0``%B@`0``````$``7```$``"@1@``?````!(`#0#``P``
ME$<````````2``X`.`0``.PW``"$"@``$@`-`'D#``#(%0``G`(``!(`#0#&
M`P``,#````0````2``T`UP,``$"0`0``````$``7`+\$```T,```@`(``!(`
M#0"Y!```J!(````````2``L`[`0``'!"```P!```$@`-`*L$``!`D`$`````
M`!``%P`?!```M#(``"@````2``T`4@0``)Q'```$````$0`/`)$$``!8H`$`
M`````!``%P"6!```6*`!```````0`!<`MP0``(PN``!0````$@`-`,P$``#T
M-@``^````!(`#0#>!```/#8``*`````2``T`100```"0`0``````$``6`"P$
M``#<,@``.`$``!(`#0`,!```0)`!```````0`!8`AP0``#R0`0`$````$0`6
M`+8#``"01P``!````!(`#0!W!```,$<``&`````2``T`2P0``&08````````
M$@`-`$<$````D`$``````"``%@#E`P``W#8``!@````2``T`$P0``%B@`0``
M````$``7`&$$``!,+P``Y````!(`#0">!```%#0``"@"```2``T``&QI8G!E
M<FPN<V\N-2XR.`!?251-7V1E<F5G:7-T97)434-L;VYE5&%B;&4`7U]G;6]N
M7W-T87)T7U\`7TE435]R96=I<W1E<E1-0VQO;F5486)L90!097)L7W-Y<U]T
M97)M`%!E<FQ?<WES7VEN:70S`%!E<FQ?871F;W)K7VQO8VL`<&5R;%]C;VYS
M=')U8W0`4&5R;%]G971?<W8`4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%]A
M=E]S:&EF=`!097)L7W-V7S)P=E]F;&%G<P!097)L7W-V7W-E='!V;@!03%]D
M;U]U;F1U;7``4&5R;%]N97=84U]F;&%G<P!03%]T:')?:V5Y`'!E<FQ?9G)E
M90!097)L7VUG7W-E=`!097)L7V%T9F]R:U]U;FQO8VL`4&5R;%]S=E]S971P
M=@!097)L7V=V7V9E=&-H<'8`<&5R;%]R=6X`4&5R;%]N97=84P!P97)L7V1E
M<W1R=6-T`%!E<FQ?879?9F5T8V@`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?<&%R
M<V4`4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?86QL;V,`4$Q?;65M;W)Y7W=R
M87``;&EB9&PN<V\N,@!L:6)M+G-O+C8`;&EB<'1H<F5A9"YS;RXP`'!T:')E
M861?9V5T<W!E8VEF:6,`8VQO<V4`;W!E;C8T`%]?97)R;F]?;&]C871I;VX`
M;'-E96LV-`!R96%D`&QI8F,N<V\N-@!?7W)E9VES=&5R7V%T9F]R:P!E>&ET
M`'-T<FYC;7``8VQO<V5D:7(`7U]S=&%C:U]C:&M?9F%I;`!U;FQI;FL`;6MD
M:7(`<F5A;&QO8P!A8F]R=`!M96UC:'(`9V5T<&ED`'-T<F1U<`!S=')T;VL`
M<W1R;&5N`&UE;7-E=`!S=')S='(`<FUD:7(`7U]F<')I;G1F7V-H:P!M96UC
M<'D`7U]S=')N8W!Y7V-H:P!?7VQX<W1A=#8T`&]P96YD:7(`7U]X<W1A=#8T
M`'-T9&5R<@!G971U:60`<F5A9&QI;FL`7U]M96UC<'E?8VAK`'-T<F-H<@!R
M96%D9&ER-C0`7U]C>&%?9FEN86QI>F4`7U]S<')I;G1F7V-H:P!M96UM;W9E
M`&%C8V5S<P!S=')C;7``7U]L:6)C7W-T87)T7VUA:6X`7U]E;G9I<F]N`&QD
M+6QI;G5X+G-O+C,`7U]S=&%C:U]C:&M?9W5A<F0`;&EB8W)Y<'0N<V\N,0!?
M7VQI8F-?8W-U7V9I;FD`<&%R7V-U<G)E;G1?97AE8P!?7V)S<U]S=&%R=%]?
M`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P`%]E9&%T
M80!?7V)S<U]E;F1?7P!P87)?8F%S96YA;64`<&%R7V1I<FYA;64`<&%R7VUK
M=&UP9&ER`%]?9&%T85]S=&%R=`!?24]?<W1D:6Y?=7-E9`!P87)?8W5R<F5N
M=%]E>&5C7W!R;V,`7U]L:6)C7V-S=5]I;FET`&UY7W!A<E]P;`!?96YD`%]?
M96YD7U\`<&%R7VEN:71?96YV`%]?8G-S7W-T87)T`'AS7VEN:70`<&%R7V9I
M;F1P<F]G`'!A<E]S971U<%]L:6)P871H`'!A<E]E;G9?8VQE86X`6%-?26YT
M97)N86QS7U!!4E]"3T]4`$=,24)#7S(N-``````````"``(``@`"``(````#
M``(``@`"``0````"`````@```````@`"``(``@`"``(````````````"``(`
M`@```````P````(``P`"``(```````(``@`"```````"`````P`"```````"
M``(````````````"`````@`"``(```````(``@`````````"``(``@`"``,`
M`@`"``,``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!`(@#```0````(````!1I:0T```0`
M`@4````````!``$`X`$``!`````@````%&EI#0```P`"!0````````$``0`O
M`@``$``````````4:6D-```"``(%````````A(T!`!<```"(C0$`%P```,"/
M`0`7````Z(\!`!<```#PCP$`%P````20`0`7````#)`!`!<````0D`$`%P``
M`!B0`0`7````')`!`!<````@D`$`%P```"20`0`7````*)`!`!<````PD`$`
M%P```#20`0`7````/)`!`!<```#$CP$`%04``,B/`0`5"```S(\!`!4-``#0
MCP$`%1```-2/`0`5&@``V(\!`!4<``#<CP$`%1\``."/`0`5*@``Y(\!`!4N
M``#LCP$`%3@``/2/`0`50@``^(\!`!5'``#\CP$`%4@``,".`0`6`P``Q(X!
M`!8$``#(C@$`%@4``,R.`0`6!P``T(X!`!8)``#4C@$`%@H``-B.`0`6"P``
MW(X!`!8,``#@C@$`%@X``.2.`0`6#P``Z(X!`!81``#LC@$`%A(``/".`0`6
M$P``](X!`!84``#XC@$`%A4``/R.`0`6%@```(\!`!87```$CP$`%A@```B/
M`0`6&0``#(\!`!8;```0CP$`%AT``!2/`0`6'@``&(\!`!8@```<CP$`%B$`
M`""/`0`6(@``)(\!`!8C```HCP$`%B0``"R/`0`6)0``,(\!`!8F```TCP$`
M%B<``#B/`0`6*```/(\!`!8I``!`CP$`%BH``$2/`0`6*P``2(\!`!8L``!,
MCP$`%BT``%"/`0`6+P``5(\!`!8P``!8CP$`%C$``%R/`0`6,@``8(\!`!8S
M``!DCP$`%C0``&B/`0`6-0``;(\!`!8V``!PCP$`%C<``'2/`0`6.0``>(\!
M`!8Z``!\CP$`%CL``("/`0`6/```A(\!`!8]``"(CP$`%CX``(R/`0`6/P``
MD(\!`!9```"4CP$`%D$``)B/`0`61```G(\!`!9%``"@CP$`%D8``*2/`0`6
M20``J(\!`!9*``"LCP$`%DL``+"/`0`63```M(\!`!9-``"XCP$`%DX``+R/
M`0`63P``"$`MZ8(!`.L(@+WH!.`MY03@G^4.X(_@"/"^Y?![`0``QH_B%\J,
MXO#[O.4`QH_B%\J,XNC[O.4`QH_B%\J,XN#[O.4`QH_B%\J,XMC[O.4`QH_B
M%\J,XM#[O.4`QH_B%\J,XLC[O.4`QH_B%\J,XL#[O.4`QH_B%\J,XKC[O.4`
MQH_B%\J,XK#[O.4`QH_B%\J,XJC[O.4`QH_B%\J,XJ#[O.4`QH_B%\J,XIC[
MO.4`QH_B%\J,XI#[O.4`QH_B%\J,XHC[O.4`QH_B%\J,XH#[O.4`QH_B%\J,
MXGC[O.4`QH_B%\J,XG#[O.4`QH_B%\J,XFC[O.4`QH_B%\J,XF#[O.4`QH_B
M%\J,XEC[O.4`QH_B%\J,XE#[O.4`QH_B%\J,XDC[O.4`QH_B%\J,XD#[O.4`
MQH_B%\J,XCC[O.4`QH_B%\J,XC#[O.4`QH_B%\J,XBC[O.4`QH_B%\J,XB#[
MO.4`QH_B%\J,XAC[O.4`QH_B%\J,XA#[O.4`QH_B%\J,X@C[O.4`QH_B%\J,
MX@#[O.4`QH_B%\J,XOCZO.4`QH_B%\J,XO#ZO.4`QH_B%\J,XNCZO.4`QH_B
M%\J,XN#ZO.4`QH_B%\J,XMCZO.4`QH_B%\J,XM#ZO.4`QH_B%\J,XLCZO.4`
MQH_B%\J,XL#ZO.4`QH_B%\J,XKCZO.4`QH_B%\J,XK#ZO.4`QH_B%\J,XJCZ
MO.4`QH_B%\J,XJ#ZO.4`QH_B%\J,XICZO.4`QH_B%\J,XI#ZO.4`QH_B%\J,
MXHCZO.4`QH_B%\J,XH#ZO.4`QH_B%\J,XGCZO.4`QH_B%\J,XG#ZO.4`QH_B
M%\J,XFCZO.4`QH_B%\J,XF#ZO.4`QH_B%\J,XECZO.4`QH_B%\J,XE#ZO.4`
MQH_B%\J,XDCZO.4`QH_B%\J,XD#ZO.4`QH_B%\J,XCCZO.4`QH_B%\J,XC#Z
MO.4`QH_B%\J,XBCZO.4`QH_B%\J,XB#ZO.4`QH_B%\J,XACZO.4`QH_B%\J,
MXA#ZO.4`QH_B%\J,X@CZO.4`QH_B%\J,X@#ZO.4`QH_B%\J,XOCYO.7P0"WI
M1%*?Y40RG^4DT$WB!5"/X!0`C>40$(WE#""-Y0-`E><,((WB`#"4Y1`0C>(4
M`(WB'#"-Y9S__^L4(I_E%#*?Y0(@E><#`)7G`A"@X3\,`.L$,I_E`S"5YP!P
MT^4``%?C4P``"O0QG^4#8)7G``"6Y=[__^O&,]#E`""@X0(P@^/&,\+E``"6
MY=C__^L4,)WE!3"#X@<!<^/&(]#E`2""X\8CP.5@``"*`P&@X6#__^NL$9_E
M$#"=Y0$0C^``P)/E%""=Y0$`4N,`X*#A``"1Y9`1G^4(`([E`1"/X(@!G^4$
M$([EA!&?Y0``C^``P([E`1"/X`P`CN4$P$/"!`"@XP%`@>D"P8S`#!".P@,`
M`-H$`+/E!`"AY0,`7.'[__\:3%&?Y0`0H.,-P8+B!5"/X!``E>4`$(WE#!&.
MYS01G^4#((+B#C"@X0$0C^!W___K`&!0XB,```H<49_E&'"-X@50C^`0`)7E
M'/__ZPP!G^4'$*#A``"/X"($`.L``%#C'```"O@PG^4#,(_@$`"3Y?W^_^M?
M___K'""=Y0`PE.4&`*#A`P!2X28``!HDT(WB\("]Z!C__^O(,)_E`S"/X```
M4.,0`(/E'```"NO^_^N(,)_E`V"5YP``EN6#___K<7?`Y:#__^H0`)7E:O__
MZP!@H.'7___J#`"5Y0``4.,!```*L@L`Z]W__^IX`)_E!Q"@X0``C^#Z`P#K
M``!0XPP`A>76__\*]?__ZEPPG^5<`)_E`Q"5YP``C^`I___K`0"@XQ+__^O8
M_O_KU'@!`!@!```X`0``0`$``"0!```@`0``L'D!`#0T```H-```@'D!`$1Y
M`0#`%P``$'D!`%`Q``#H>`$`M'@!`$PP```P`0``##(```"PH.,`X*#C!!"=
MY`T@H.$$("WE!``MY2B@G^4D,(_B`Z"*X"#`G^4,P)KG!,`MY1@PG^4#,)KG
M%`"?Y0``FN?A_O_K-___ZPAV`0`,`0``-`$``#P!```4,)_E%""?Y0,PC^`"
M()/G``!2XQ[_+P';_O_JZ'4!`"P!```L`)_E+#"?Y0``C^`#,(_@``!3X2`P
MG^4#,(_@'O\O`1@@G^4",)/G``!3XQ[_+P$3_R_A4'<!`$QW`0"T=0$`%`$`
M`#@`G^4X,)_E``"/X`,PC^``$$/@01&@X:$?@>`D,)_EP1"PX0,PC^`>_R\!
M&""?Y0(PD^<``%/C'O\O`1/_+^$,=P$`"'<!`&1U`0!$`0``3#"?Y4P@G^4#
M,(_@`##3Y0(@C^```%/C'O\O$3@PG^400"WI`S"2YP``4^,"```**#"?Y0,`
MG^=+_O_KRO__ZQPPG^4!(*#C`S"/X``@P^40@+WHO'8!`"AU`0`0`0``5'8!
M`'QV`0#0___JU#V?Y=0MG^4#,(_@\$\MZ:7?3>("()/G"."-X@0@C>5`P(#B
M`""2Y8!0@.(.$*#A`$"@XXPBC>4$8!SE"'`<Y28TH.'_/`/B9R@GX"8\@^$&
MA*#A(B2@X08\@^$(P(SB_V@(XO\LPN,&,(/A9R0BX`P`5>$$0('E#$"!Y0@P
M@>4`(('E$!"!XNK__QI^[X[B#1"@X0!`H.,!P*#A2%"1Y7`PD>5T()SE3'"<
MY1B`D>4(8+'E!3`CX!Q0G.4(,"/@!,"1Y0<@(N`&,"/@!2`BX`P@(N"CSZ#A
M@L",X8,PC.$.`%'AA$"!Y8`P@>7I__\:"%"0Y0S`D.4E0:#A$""-X@!PD.40
M8)#E#$^$X1C`D.7,/)_E!!"0Y0B0$N6G[:#A#(`FX"#`D.4#D)G@@>*.X0R0
MF>"'XH[A">">X!B0D.4%@`C@!4^$X0"@DN4)@"C@".">X`3`)N`8@)#E)Y&@
MX0?`#.`!GXGA`Q":X`>?B>$(H)+E!L`LX`@0D>`,$)'@"8`DX.[-H.$,$)'@
M#H`(X`/`FN!NX:#A$+"2Y02`*.`&P)S@X:V@X0C`G.`.@"G@"L"<X`&`".`#
MH)O@81&@X1BPDN4$0)K@"8`HX.RMH.$(@)3@`4`NX`J`F.`,0`3@`Z";X&S!
MH.$@L)+E#D`DX`F0FN`$D)G@Z*V@X0Q`(>`*D)G@"$`$X`.@F^!H@:#A*+"2
MY0[@FN`!0"3@Z:V@X01`GN`(X"S@"D"4X`G@#N`#H)O@:9&@X3"PDN4!$)K@
M#.`NX.2MH.$.X)'@"1`HX`K@GN`$$`'@`Z";X&1!H.$XL)+E"!`AX`S`FN`!
MP)S@[JV@X000*>`*P)S@#A`!X`.@F^!NX:#A0+"2Y0D0(>`(@)K@`8"8X.RM
MH.$.$"3@"H"8X`P0`>`#H)O@;,&@X4BPDN4$$"'@"9":X`&0F>#HK:#A#!`N
MX`J0F>`($`'@`Z";X&B!H.%0L)+E#A`AX`1`FN`!0)3@Z:V@X0@0+.`*0)3@
M"1`!X`.@F^!ID:#A6+"2Y0P0(>`.X)K@`>">X.2MH.$)$"C@"N">X`00`>`#
MH)O@9$&@X6"PDN4($"'@#,":X`'`G.#NK:#A!!`IX`K`G.`.$`'@`Z";X&[A
MH.%HL)+E"1`AX`B`FN`!@)C@[*V@X0X0).`*@)C@#!`!X`.@F^!LP:#A<+"2
MY000(>`)D)K@`9"9X.BMH.$,$"[@"I"9X`@0`>`#H)O@:(&@X7BPDN4.$"'@
M!$":X`%`E.#IK:#A"!`LX`I`E.`)$`'@`Z";X&F1H.&`L)+E#!`AX`[@FN`!
MX)[@Y*V@X0D0*.`*X)[@!!`!X`.@F^!D0:#AB+"2Y0@0(>`,P)K@`<"<X.ZM
MH.$$$"G@"L"<X`X0`>`#H)O@"*":X)"PDN5N@:#A"1`AX`C@).`!$)K@[*V@
MX0H0D>`,X`[@`S";X`F0D^"8L)+EG#F?Y02@+N`*H)G@;)&@X>'-H.$,H)K@
M">`HX`/`F^`!X"[@H+"2Y03`G.`.P)S@8>&@X>H=H.$!P)S@#D`IX`,0F^`*
M0"3@"!"1X`00D>#LC:#A"!"1X*B`DN5J0:#A!+`NX`.`F.`)D)C@#*`KX+"P
MDN5LP:#AX8V@X0J@F>`(H)K@#)`DX`.`F^`!D"G@#H"8X`F`F.#J[:#A#H"8
MX+C@DN5A$:#A`;`LX`/@GN`$0)[@"I`KX`F0E.#H3:#A!)"9X,!`DN5JX:#A
M#K`AX`-`E.`,P)3@"*`KX`J@G.#IS:#A#*":X,C`DN5H0:#A!+`NX`/`G.`!
M$)S@"8`KX`B`D>#J':#A`8"8X-`0DN5IP:#A#+`DX`,0D>`.X)'@"I`KX`F0
MGN#H[:#A#I"9X-C@DN5J$:#A`;`LX`/@GN`$0)[@"*`KX`J@E.#I3:#A!*":
MX.!`DN5HX:#A#K`AX`-`E.`,P)3@"8`KX`B`G.#JS:#A#("8X.C`DN5I0:#A
M!+`NX`/`G.`!$)S@"I`KX/"PDN5JP:#A"9"1X.@=H.$!D)G@#*`DX`,0F^`.
M$)'@^."2Y0@@*N`"()'@:!&@X>F-H.$(()+@`:`LX`.`GN`)H"K@!("8X!!!
MG>5IX:#A"H"8X.*=H.$)@)C@#K`AX`-`E.`,P)3@`I`KX!A!G>5B(:#A"9"<
MX.C-H.$,D)G@`L`NX`-`E.`(P"S@`4"4X"`1G>4,0)3@:,&@X>F-H.$(0)3@
M#+`BX`,0D>`.$)'@"8`KX"BQG>7D[:#A"("1X&D1H.$.@)C@`9`LX`/@F^`$
MD"G@`N">X#`AG>5D0:#A">">X.B=H.$)X)[@!*`AX`,@DN`(H"K@.+&=Y0S`
MDN`*P)S@:"&@X>Z-H.$(P)S@`J`DX`.`F^`.H"K@`1"8X$"!G>5NX:#A[)V@
MX0H0D>`)$)'@#I`BX`.`F.`$0)C@T#:?Y0R`*>!(L9WE;,&@X0R0CN$(@)3@
MX4V@X02`F.`!D`G@`T";X`RP#N!A$:#A4*&=Y0NPB>$"0)3@`9",X>@MH.$+
M0)3@`D"4X`&P#.`(D`G@`R":X`X@DN`+X(GA:(&@X>2=H.$"X)[@">">X`@@
MH.$(L('A")`!X%B!G>4$L`O@`X"8X&1!H.$)D(OA#,"8X&"QG>4$H(+A[HV@
MX0S`F>`(P)S@#J`*X`2``N`#L)O@`1";X`B`BN$!@)C@[!V@X6[AH.$!@)C@
M:!&=Y0ZPA.$,L`O@#J`$X`,0D>!LP:#A"J"+X0(@D>!PL9WE#)".X>@=H.$"
M()K@`:"2X`B0">`,(`[@`Q";X`*0B>$$$)'@ZBV@X0$0F>!H@:#A`A"1X'@A
MG>4(0(SA"I`$X`,@DN`(0`S@:J&@X01`B>$.()+@@)&=Y0K@B.$"()3@X4V@
MX01`DN`!X`[@"B`(X`.0F>`"X([A#,"9X.0MH.$,P)[@81&@X0+`G."((9WE
M`9"*X020">`!X`K@`R"2X&1!H.$.X(GA"""2X)"1G>4$@('A`B">X.SMH.$.
M()+@#(`(X`3@`>`#D)G@;,&@X0Z`B.$*D)G@F+&=Y0R@A.'B[:#A"9"8X`Z0
MF>`"H`K@#.`$X`.PF^!B@:#A`1";X`X@BN&@H9WE".",X0$@DN#I':#A`2"2
MX`BP#.`)X`[@`Z":X&D1H.$$H)K@"^".X:BQG>4!0(CAXIV@X0K@GN`)X)[@
M`D`$X`.0F^`!H`C@8B&@X0J@A.&PL9WE#,"9X`)`@>'NG:#A#,":X`G`G.`"
MH`'@`Y";X`Y`!.`(D)G@;N&@X0I`A.&XL9WE#H""X0E`E.#LG:#A"4"4X`R`
M".`#D)O@#J`"X,"QG>5LP:#A"J"(X0$0F>`,@([AY)V@X0$0FN`)$)'@!(`(
MX`.0F^`,H`[@9$&@X0J@B.'(L9WE`B"9X`2`C.'AG:#A`B":X`D@DN`$H`S@
M`Y";X`&`".`.D)G@81&@X="QG>4*@(CA`>"$X0F`F.#BG:#A"8"8X`&@!.`#
MD)O@`N`.X`K@CN%B(:#AV+&=Y0S`F>`"H('A#,">X.CMH.$.P)S@"*`*X`*0
M`>`#X)O@:(&@X0F0BN$$X)[@X*&=Y0A`@N$.X)G@[)V@X0G@GN`,0`3@")`"
MX`,PFN`)0(3AZ*&=Y0$0D^!4,Y_E;,&@X>Z=H.$!$)3@"1"1X`Q`*.`#D)K@
M#D`DX/"QG>4"()G@!""2X&Z1H.'A3:#A!$"2X`F@+.`#()O@"."2X`&@*N#X
ML9WE81&@X>0MH.$*X)[@`N">X`&`*>`#()O@!(`HX`"RG>4,()+@"""2X&3!
MH.'N3:#A!""2X`R@(>`#0)O@"8"4X`Z@*N`(LIWE;N&@X>)-H.$*@)C@!("8
MX`Z0+.`#0)O@`I`IX!"RG>4!0)3@8B&@X>@=H.$)0)3@`4"4X`*@+N`#$)O@
M#,"1X`B0*N`8LIWE:!&@X0F0G.#DS:#A#)"9X`&@(N`#P)O@#N"<X`2`*N`@
MLIWE9,&@X0B`GN#I[:#A#H"8X`R@(>`#X)O@`B">X`E`*N`HLIWE:>&@X01`
MDN#H+:#A`D"4X`Z@+.`#()O@`1"2X`B0*N`PLIWE:"&@X0F0D>#D':#A`9"9
MX`*@+N`#$)O@#,"1X`2`*N`XLIWE9!&@X0B`G.#IS:#A#("8X`&@(N`#P)O@
M#N"<X`E`*N!`LIWE:<&@X01`GN#H[:#A#D"4X`R@(>`#X)O@`B">X`B0*N!(
MLIWE:.&@X0F0DN#D+:#A`I"9X`Z@+.`#()O@`1"2X`2`*N!0LIWE9"&@X0B`
MD>#I':#A`8"8X`*@+N`#$)O@#,"1X`E`*N!8HIWE:1&@X01`G.#HS:#A#$"4
MX`&0(N`#P)K@")`IX&"BG>4.X)S@">">X&C!H.'DC:#A".">X`R0(>`#@)K@
M!)`IX&BBG>4"()C@9$&@X>Z-H.$)()+@"""2X`20+.`#@)K@#I`IX'"BG>4!
M$)C@;N&@X>*-H.$)$)'@"!"1X`Z0).`#@)K@`I`IX'BBG>4,P)C@8B&@X>&-
MH.$)P)S@","<X`.0FN`"@"[@@**=Y0&`*.`$0)G@81&@X0A`E.`!D"+@[(V@
MX0,PFN`(0(3@#C"3X`R0*>#D[:#A"3"3X`XP@^`8X)#E;,&@X0=PD^`$0)7@
M!L"<X`X0D>`@X)#E`#"@XPX@DN`@((#E`'"`Y0A`@.40P(#E&!"`Y00P@.4,
M,(#E%#"`Y1PP@.4D,(#E!#"=Y8PBG>4`,)/E`P!2X0$``!JEWXWB\(^]Z._Z
M_^O$=`$`&`$``)EY@EJAZ]ENW+P;C];!8LK0,)_E\$<MZ0!P4.(#,(_@+```
M"L`@G^4",)/G`)"3Y0``6>,I```*`##7Y3U04^(!4*`3``!3XP!0H`,``%7C
M$@``&@!`F>4``%3C#0``"@&`H.$)8*#A!2"@X0<0H.$$`*#A4/O_ZP``4.,"
M```:!3#4YST`4^,+```*!$"VY0``5./S__\:!`"@X?"'O>@'4*#A`3#UY0``
M4^,]`%,3^___&@=01>#E___J"6!&X`%0A>)&8:#A!4"$X`!@B.4$`*#A\(>]
MZ`=`H.'M___J"4"@X>O__^K,9@$`2`$``/!`+>F(<)_EB#"?Y0=PC^`#8)?G
M#-!-X@`PEN4`4*#A#4"@X00PC>4$$*#A!0"@X;K__^L``%#C#@``"E@PG^4`
M`)WE`S"7YP`0D^4`,8'@!""3Y0`A@><``%+C\?__"@0P@^($()/E!""#Y```
M4N/[__\:Z___Z@0@G>4`,);E`P!2X0$``!H,T(WB\("]Z(SZ_^OL90$`&`$`
M`$@!``#P3RWI$)*?Y0`@T>4,,I_E"9"/X#T`4N,#8)GG`4"@X0%`@0(4T$WB
M`#"6Y0!0H.$$`*#A##"-Y;;Z_^L($(WB`'"@X04`H.&,___K`(!0XCX```JO
M^O_K!P!0X34``"J\,9_E"("=Y0.0F><(@:#A`##5Y3T`4^(!`*`3``!3XP``
MH`,``%#C!0``"@4`H.$!,/#E``!3XST`4Q/[__\:!0!`X`)PA^(``(?@`'"9
MY8;Z_^L``%#C"`"'YU$```H`()GE"!"=Y04`H.$!,-#D`1&2YST`4^,``%,3
M`##!Y08```H!(('B`3#0Y`(0H.$``%/C/0!3$P$PPN3Y__\:/3"@XP$@H.$`
M,,'E`3#4Y`$PXN4``%/C^___&@``H.,,()WE`#"6Y0,`4N$Y```:%-"-XO"/
MO>@!,$CB`2#4Y`$@X^4``%+C^___&O+__^K,,)_E`Y"9YP"PF>4`H)OE``!:
MXRD```H(,*#A"R"@X0```.H*,*#A!!"RY0&@@^(``%'C^O__&@,P@^(#$:#A
MD#"?Y0,PC^``()/E``!2XQ$``!H!(*#C`0"@X0`@@^5&^O_K`#!0X@0PC>41
M```*"H&@X0L0H.$((*#A^OG_ZP0PG>4`,(GE`2"*X@`0H.,"$8/G"*"-Y:#_
M_^H+`*#A%?K_ZP``4.,`,*#A``")Y0J!H!'S__\:``#@X\/__^H($*#CW?__
MZ@+Z_^M(90$`&`$``$@!``!490$`2#&?Y4@AG^4#,(_@\$\MZ0)0D^=\T$WB
M`#"5Y0!@4.)T,(WE`@``"@`PUN4``%/C!0``&G0@G>4`,)7E`P!2X4$``!I\
MT(WB\(^]Z`[Z_^L`<%#B]O__"OB`G^7XD)_E^*"?Y0B`C^`)D(_@"J"/X`<`
MH.%5^O_K``!0XRL```H30(#B!`"@X0@0H.&P^?_K``!0X_7__PH)$*#A!`"@
MX:OY_^L``%#C\/__"@8`H.$-^O_K`+"@X00`H.$*^O_K``"+X`(`@.+U^?_K
M"C"@X0`@X.,!$*#C!$"-Y0!@C>4`L*#A#_K_ZPL0H.$(((WB`P"@XS[Z_^L!
M`'#C"P"@X0,```H8,)WE#SH#X@$)4^,+```*OOG_ZPL`H.&>^?_K!P"@X2GZ
M_^L``%#CT___&@<`H.$]^O_K!@"@X9_Y_^N[___JK?__Z_+__^JJ^?_K)&,!
M`!@!``#D&P``Y!L``.0;``"`,)_E@""?Y0,PC^`P0"WI`D"3YW303>(`$*#A
M`,"4Y0!0H.$-(*#A`P"@XVS`C>4B^O_K``!0XP``H!,$```:$#"=Y0\Z`^(*
M"E/C`0E3$P4```IL()WE`#"4Y0,`4N$'```:=-"-XC"`O>@%`*#A`A"@X_/Y
M_^L0#V_AH`*@X?/__^J#^?_KP&$!`!@!``#P1RWI^$"?Y?@PG^4$0(_@`=I-
MX@C03>(#@)3G`)"@X>0`G^4!RHWB!&"-X@`PF.4$P(SB`:"@X=`@G^4&$*#A
M``"/X``PC.6`^?_K``!0XR$``-H(4(WB`7!`X@=0A>"L,)_E!"!5Y0,PE.<`
M`%+C`$"3Y18``!H``%?C&0``"@<@H.$O$*#C!@"@X<;Y_^L``%#C$P``"@0`
MH.'I^?_K!S"@X08@H.$)$*#AS?G_ZP$ZC>($,(/B`""3Y0`PF.4#`%+A#0``
M&@':C>((T(WB\(>]Z`!PH.'H___J,#"?Y0,PE.<`0)/E!`"@X=7Y_^L*(*#A
M"1"@X5'Y_^OK___J0/G_ZRQA`0`8`0``)!H``/\/```@`0``$$`MZ3!`G^4P
M,)_E!$"/X`,PE.<``)/EQ/G_ZR`@G^4@,)_E(!"?Y0(@E.<#,(_@`1"/X!!`
MO>A]^?_J%&`!`"`!```<`0``X!@``"P9``!4,)_E5""?Y0,PC^`00"WI`D"3
MYPC03>(``)3EK_G_Z^+__^L``)3EK/G_ZP`@H.,L,)_E!""-Y2@0G^4H()_E
M`S"/X``PC>4"((_@`1"/X'CY_^L(T(WB$("]Z,A?`0`@`0``N!L``-P8``!$
M$P``R#"?Y<@@G^7P0"WI`S"/X`+:3>(<T$WB`E"3YP(JC>(4((+B`#"5Y0`P
M@N4U^?_KH#"?Y0Q`C>(#,(_@!#"-Y90PG^4!:HWB`S"/X(P@G^4!$*#C$&"&
MX@``C>4$`*#A/?G_ZP0`H.$&$*#A`2J@XP#Y_^L`0%#B`'"@LP@``+H!`(3B
M$_G_ZP!P4.($```*!A"@X00@H.'2^/_K`#"@XP0PQ^<".HWB%#"#X@`@D^4`
M,)7E!P"@X0,`4N$"```:`MJ-XAS0C>+P@+WHU_C_ZU1?`0`8`0``I!@``(@8
M```!$```Q?__ZD0RG^5$(I_E\$\MZ0,PC^!"W4WB%-!-X@(@D^<`<*#A+`*?
MY2"`C>)"/8WB##"#XA@@C>4!0*#A`""2Y0@0H.$``(_@`""#Y=3]_^LO$*#C
M`%"@X0<`H.'\^/_K``!0XPX```KL`9_E!Q"@X0``C^`J_O_K!P"@X4(]C>(,
M,(/B`""3Y1@PG>4`,)/E`P!2X6P``!I"W8WB%-"-XO"/O>@'`*#AX_C_ZZP1
MG^4!$(_@`*"@X00`H.$1^?_K`+!0XN?__PJ4,9_EE)&?Y0,PC^`4,(WEC#&?
MY0,PC^`<,(WE`##;Y0``4^,X```*``!5XP0```H+$*#A!0"@X6?X_^L``%#C
M.@``"@L`H.')^/_K`3!`X@,0V^<#,(O@+P!1XP4``!H`P*#C`,##Y0$@<^4!
M`$#B+P!2X_K__PH!,(KB``"#X`D`4.'%___*&#&?Y8Q`C>(#,(_@!#"-Y0PQ
MG^4!*J#C`S"/X`$0H.,(<(WE`+"-Y00`H.&]^/_K"""@X000H.$#`*#C[/C_
MZY!@C>(``%#C`P``&F`P%N4/.@/B`@E3XQ@```K$$)_E``"@XP$0C^#2^/_K
M`+"@X0``6^.G__\*`##;Y0``4^/&__\:``!5XQ@```H4$)WE!0"@X2[X_^L`
M`%#C%+"=%0$`H!/1__\:?!"?Y0``H.,!$(_@O_C_ZP"PH.'K___J`1"@XP0`
MH.&W^/_K``!0X^'__QI4`)_E!!"@X0``C^"[_?_K!`"@X4#X_^N.___J'+"=
MY0$`H..\___J/OC_ZVQ>`0`8`0``N!<``)@7``!H%P``R!8``/\/``"\%@``
MS!8``+06``!D%@``&!8``-P5````,-#E``!3XQ[_+P$!((#B+P!3XP(`H`$!
M,-+D``!3X_K__QH>_R_A$$`MZ0!`4.(\```*`##4Y0``4^,Y```*7/C_ZP$`
M0.(`,(3@`P!4X0L``"H`(-3G+P!2XQ$``!H!($/B`P``Z@`0TN4!($+B+P!1
MXPL``!H$`%+A`C"@X?C__QH#`%3A$```&@`PU.4O`%/C*0``"K``G^400+WH
M``"/X`3X_^H!($/B`P``Z@`0TN4!($+B+P!1XP,```H"`%3A`C"@X?C__SKL
M___J`3!#X@,``.H`$-/E`3!#XB\`4>,"```:`P!4X0,@H.'X__\Z!"!"X`(P
M@N(!"E/C#```BD@`G^4$$*#A``"/X`!`H.$!((+B`3J@X^/W_^L$`*#A$("]
MZ"@`G^400+WH``"/X.#W_^H``*#C$("]Z!0`G^400+WH``"/X-KW_^H`%0``
MD%P!`.03``#,$P``O,&?Y7!`+>D,P(_@#,",X@\`O.BL09_E,-!-XJA1G^4$
M0(_@"."-X@50E.</`*[H#P"\Z`\`KNB0`9_E`""<Y0`PE>4``(_@L"#.X2PP
MC>42_?_K>`&?Y7AAG^4``(_@#OW_ZW`!G^4&8(_@``"/X`K]_^MD`9_E!$"-
MX@``C^`&_?_K6`&?Y0``C^`#_?_K4`&?Y0``C^``_?_K2`&?Y0``C^#]_/_K
M0`&?Y0``C^#Z_/_K!@"@X?C\_^LP`9_E``"/X/7\_^LH`9_E``"/X/+\_^L@
M`9_E!!"@X0``C^"V_/_K`!!0X@$```H&`*#A$OW_ZP0!G^4$$*#A``"/X*[\
M_^L`$%#B`@``"O``G^4``(_@"?W_Z^@`G^4$$*#A``"/X*7\_^L`$%#B#0``
M"M0`G^4``(_@`/W_Z\P0G^7,`)_E`1"/X```C^#[_/_K+""=Y0`PE>4#`%+A
M%P``&C#0C>)P@+WHJ`"?Y000H.$``(_@D?S_ZP`04.(#```*E`"?Y0``C^#L
M_/_KZO__ZH@0G^4*(*#C`1"/X!D`C>+Q]__K``!0X^/__QIP`)_E(Q"-X@``
MC^#@_/_KWO__ZFCW_^M\$P``>%H!`!@!````%```]!,``"P4``#L$P``Z!,`
M`.03``#H$P``>!,``-P3``#@$P``6!,``-`3``#$$P``Q!,``,`3``#D$@``
MS!,``"03``"`$P``!!,``&P3``#4$@``A#"?Y80@G^6$$)_E`S"/X`(@C^`0
M0"WI`4"3YP``DN4(T$WB`""4Y0$`<.,$((WE!0``"@0@G>4`,)3E`P!2X1``
M`!H(T(WB$("]Z$0`G^4-$*#A``"/X$[\_^L``%#C!```"@``T.4P`%#C``!0
M$P$`H!,``*`#'#"?Y0,PC^```(/EZO__ZBSW_^MD6`$`M%D!`!@!```,$@``
M2%D!`!!`+>D']__K`/?_ZP``4.,``)`5$("]Z-@PG^78()_E\$$MZ0,PC^#0
M8)_E`D"3YQC03>(&8(_@`%"@X0`@E.40$(WB!@"@X10@C>4I_/_K!1"@X0!P
M4.("```*`##7Y0``4^,(```:E`"?Y0``C^"`_/_K%""=Y0`PE.4#`%+A&P``
M&AC0C>+P@;WHUO;_ZP``4./V__\:!0"@X3OW_^L`@*#A!P"@X3CW_^L``(C@
M`@"`XB/W_^M(,)_E"'"-Y0,PC^`$,(WE/#"?Y0!0C>4#,(_@`"#@XP$0H.,`
M@*#A.??_ZP@0H.$&`*#A8?S_Z]___^KI]O_KK%<!`!@!```8$@``X!$``*P0
M``"@$```9,F?Y?!/+>F!W$WBG-!-X@S`C^`@`(WE4*F?Y0<`G.EF3XWB2.F?
MY0J@C^#X,$3B$%",X@Y@FN<'`(/H#P"UZ.#@1.(/`*[H`P"5Z"C`C.(#`([H
M!P"<Z.PP1.('`(/H$`F?Y8$LC>(X<(WB`#"6Y90@@N('$*#A``"/X"A@C>4`
M,(+EU_O_ZP!04.("```*`##5Y0``4^,<`0`:D___ZP!@4.+Y```*!@"@X?/V
M_^N``*#A`0"`XM[V_^L`,-;E``!3XR0`C>4,```*J+B?Y210G>4+L(_@`#"-
MY04`H.$+,*#A`"#@XP$0H./R]O_K`3#VY0)0A>(``%/C]?__&N``%.4``%#C
M$@``"MQ01.("``#J!`"5Y```4.,-```*!Q"@X:_[_^L`8%#B^/__"@`PUN4`
M`%/C]?__"NW\_^L``%#C\O__"@8`H.&,]O_K`+!0XAX``!H`D*#C^&!$X@DQ
MA.#X4!/E``!5XQ<```H`,-7E``!3XQ0```H!@(GB"+&&X`4`H.':_/_K")"@
MX0``4.,'```:!%";Y```5>,*```*`##5Y0``4^,'```*`8"(XO+__^H%`*#A
M</;_ZP``4./E__\*`+"@X0```.H`L*#C"P"@X:CV_^LD@)WE`%"@X0@`H.&D
M]O_K`%"%X`%;A>($4(7B!0"@X8WV_^MX-Y_E>">?Y0,PC^`$,(WE<#>?Y0(@
MC^`(((WE`S"/X``@X.,!$*#C#("-Y0"PC>4`8*#AH/;_ZP8`H.$'':#CIO;_
MZP$`<.,#```:E_;_ZP`0D.41`%'CGP``&@<@H.$&$*#A`P"@X]+V_^L`@%#B
M%0``"A`GG^4@,)WE`A":YP@GG^4``)'E`#"3Y0(@C^``8(WE`1"@XY_V_^L`
M4*#C@3R-XI0P@^(`()/E*#"=Y04`H.$`,)/E`P!2X>\!`!J!W(WBG-"-XO"/
MO>A0,13E#SH#X@$)4^/E__\:2+$4Y0SV_^L``%OAX?__&E`Q%.6#.Z#AHSN@
MX0<-4^/<__\:!0"@X4OV_^L'$*#A`%"@X7P&G^4``(_@,OO_ZP``4..&```*
M(#"=Y0!PD^44]O_K`!"@X0<`H.%"_?_K`'!0XGX```H'`*#A3/;_ZP,`4.,`
MH*#A#```FC@6G^4$`$#B``"'X`$0C^#>]?_K``!0XP4``!H$`%KC7`$`"@J@
MA^`%,%KE+P!3XU@!``JO_O_K`!!0X@0``!H'`*#A(O;_ZP`P4.(D,(WE9P``
M&N@5G^7H!9_E`1"/X```C^!I^__K*/;_Z]@UG^78)9_E`S"/X`0PC>70-9_E
M`B"/X,REG^7,E9_ES'6?Y0P@C>4`8(WE`S"/X``@X.,!$*#C"J"/X`F0C^`'
M<(_@"`"-Y04`H.$I]O_K#@``ZB3V_^L`,)#E$0!3XQ```!H.]O_K`8"(X@R`
MC>40D(WEP`"-Z`0@H.$*,*#A`1"@XP@`C>4%`*#A&?;_ZP<=H.,%`*#A'_;_
MZP$`<.,`0*#AZO__"@8`H.&N]?_K0`6?Y040H.$``(_@./O_ZP4`H.&>_O_K
M@___Z@90H.&L@(WB!6&(X`0`EN0``%#C'@``"@<0H.'-^O_K`5"%X@`P4.+W
M__\*`##3Y0``4^/T__\*K?7_ZP``4./P__\*`&"@X?+^_^JH))_E(#"=Y0(`
MFN?0))_E`#"3Y0``D.4"((_@!!"-Y0!@C>4!$*#C!/;_ZP!0H.-C___J?/[_
MZP4`H.&9]?_K`%"@X5[__^H-`*#CPO7_ZY!DG^53,*#C!F"/X"0`C>7B_O_J
M(#"=Y0!PD^5]___J!!!$X@)PH.,`,.#C$2#@XP&`H.$`<(WE(!"-Y:;U_^L(
M$*#A!B"@XR0`G>5C]?_K!#!4Y0``4^,"```:`S!4Y4,`4^,4`0`*`'"@XP`@
MH.,`,*#C`'"-Y20`G>66]?_K.1Z/XM``P>$Y/H_BT"##X?@,1.'C'X_BT`#!
MX?`L1.'B/X_BT"##X?@+1.'A'X_BT`#!X?`K1.'0H(WB`""@XP`PH..0D$3B
M4'`$Y3!PC>7X"D3A\"I$X?@I1.$T4(WE+*"-Y0(IH.,@$)WE)`"=Y3KU_^L`
M<%#B3```VM`J1.&'$:#A`A"!X!@0C>4P$)WE'!"-Y=@!S>$'H*#A`0!3X0``
M4@''OZ#AF,`4Y90@%.4!``":`<"<X@`@HN*J/J#ABS&#X5``%.4,,)/@JQZ@
MX=BAS>$"(*'@``!0X_"J1.&8,`3EE"`$Y2X```I`L&#B"P!7X0>PH+$``(G@
M"R"@X2`0G>4D]?_K4#`4Y0,PB^!``%/C4#`$Y='__QH@,)WE+`"=Y0MP1^`+
ML(/@Q?;_ZS\`5^,4``#:0'!'XC^`Q^.`,(OB+*"=Y0.`B.!`4(OB0""@XT`0
M1>()`*#A`E"%X`WU_^L*`*#AMO;_ZP4`6.'V__\:)S.@X0$@@^(#/6/@`K.+
MX`-SA^`LH(WE"Q"@X4@PH.,'(*#A"0"@X27U_^M0<`3EKO__ZB"PG>7?___J
M)`"=Y310G>4LH)WEC_7_ZZ`0%.68D!3EH3&@X3\P`^)I*"G@87@AX)"`1.)_
M`.#C)W2@X2(DH.$#`,CG`3"#XO]\Q^/_+,+C.`!3XV%T)^!IE"+@7@``VD`@
M8^(`$*#C`P"(X$GU_^L*`*#AB?;_ZP@`H.$X(*#C`!"@XT/U_^L*`*#A6)`$
MY51P!.6!]O_KP!`4Y;@@%.5AR"'@8@@BX,@P%.6P@!3EJ'`4Y2S$H.$@!*#A
M_\S,X_\,P.-CZ"/@8<0LX&($(.!H&"C@9R@GX"[DH.$A%*#A(B2@X?_LSN/_
M','C_RS"XWRAG^5CY"[@:!0AX&<D(N`PL$3B(SR@X43@!.4*H(_@0,`$Y0MP
MH.$\``3E1(!$XC@0!.4QD$3B-"`$Y0```.H!,/CE`#"-Y0<`H.$*,*#A`"#@
MXP$0H.,&]?_K"`!9X0)PA^+U__\:&#&?Y1@AG^4#,(_@!#"-Y1`QG^4"((_@
M``"@XPP@C>4(L(WE`&"-Y0,PC^`(`$3E`"#@XP$0H.,%`*#A\_3_Z][^_^H@
M,)WE!)"3Y0``6>.B_O\*"0"@X=WT_^L#`%#CGO[_FL`0G^4$`$#B``")X`$0
MC^!P]/_K``!0XPEPH`&6_O_J`P"(X#@@8^(`$*#CZO3_ZZ7__^H!(T5G````
M`(FKS>\`````_MRZF`````!V5#(0`````/#ATL,`````!%@!`)A6`0`8`0``
MR`\``(`0``!@#@``5`\``$`/```H`0``(`\``.P.``"D#@``A`T``/@,``"<
M#```$`\``#@.```\#@``Z`X``&0,``#$"P``?`P``!@,``#T"```M`<``"@*
M``!$"0``]`@``!P&``"0"```L`<```(P5.5!`%/CY_[_&@$P5.5#`%/CY/[_
M&@`PU.5(`%/CX?[_&@$PU.5%`%/CWO[_&B1`G>4`,.#C`'"-Y3D@X.,$`*#A
M=?3_ZP0`H.$@0)WE*2"@XP00H.$Q]/_K<#`?Y7`@'^4#,(_@!#"-Y7@P'^4"
M((_@#""-Y0A`C>4`8(WE`S"/X``@X.,!$*#C!0"@X8_T_^MZ_O_J0O3_Z\PS
MG^7,$Y_E`S"/X/!/+>D!$)/G'-!-XKPCG^4,$(WE$&"-X@`0D>44$(WE"&"-
MY0)0D^<``)7EP_3_ZP!`H.$``)7EP/3_ZV@PU.4&$*#A:3#`Y80#G^4``(_@
M0/G_ZP``4.,"```*`##0Y3$`4^.U```*2OS_ZP``E>6R]/_K7!.?Y0LPH.,!
M(*#C`1"/X$WT_^L``%#C30``"D0SG^40()#E`S"/X`0PD^48@)+E`0!3XP"0
ME>5&``#:*#.?Y2BSG^4#,(_@`$"@XPNPC^`<HY_E`#"-Y0EPH.$*``#J$!"1
MY0D`H.'=\__K`#"=Y00@D^4``%#CEP``&@)`A.("`%3AE@``J@9`H.$'`*#A
MC?3_ZP0@H.$`,*#C"!"@X6OT_^L`(%#B$P``"@`0DN4(`)OE"#"1Y0%@A.(*
M,`/@`0M3XP:1D.<`<)7EX___"@<`H.$$((WE>_3_ZP0@G>4",*#C`!"2Y0`@
MH./^\__K`'"5Y0`0H.'9___J="*?Y0"0E>4"((_@!""2Y0$00N($`%'A#P``
M&@$`4N,-``#:5&*?Y0%`H.,&8(_@"0"@X0```.H``)7E8_3_ZP@0H.&\\__K
M!#"6Y0%`A.($`%/A]___R@"0E>4)`*#A6O3_ZQ@2G^4#,*#C`2"@XP$0C^#U
M\__K`$!0X@L```H``)7E4?3_ZQ`PE.7T(9_E`!"3Y0(@C^#+\__K$#"4Y0`P
MD^4(,)/E`043XUD``!H``)7E1?3_Z\P1G^4#,*#C`2"@XP$0C^#@\__K`$!0
MX@L```JT`9_E"!"=Y0``C^#`^/_K`&!0X@``E>5````*-O3_ZQ`PE.4&(*#A
M`!"3Y;'S_^L``)7E,/3_ZX!AG^4&8(_@`$"@X0``E>4K]/_K<!&?Y0$@H.,!
M$(_@W//_ZV0AG^4"((_@`!"@X00`H.&A\__K``"5Y2#T_^L`,*#C"!"=Y6DP
MP.5``9_E``"/X*#X_^L``%#C`$"@X0P`AN4-```*!QV@XP0`H.'7\__K`3"`
MXA$`4.,!`%,3*```B@PPG>44()WE`#"3Y0,`4N$B```:'-"-XO"/O>@(`);E
MDOS_ZP``4.,`0*#A#`"&Y>O__QK8`)_E``"/X+WS_^L!,-#E``!3XT?__PI%
M___J!Y"@X8G__^H'D*#A!D"@X8;__^KU\__KJ#"?Y1`@E.4#,(_@"#"3Y0``
MDN4`$)/EW/G_Z[K__^H``)7EZ_/_ZQ`PE.4`$)/EM?/_ZY___^I6\__K<""?
MY0`PH.$"((_@"!"2Y60`G^4$(*#A`!"1Y0``C^";\__K-$P!`!@!```@`0``
MN`4``#P'```H30$`"$T!``!-`0``!"``2$P!`"1,`0#D!0``Q`4``)P%``!P
M`P``0$L!`#P%``!(!0``Y`(``+P$``!02@$`%$H!`%@$``!P0"WI`%"@X0O[
M_^L`,-#E`$"@X0``4^,%```*`2"`XB\`4^,"0*`!`3#2Y```4^/Z__\:V/O_
MZP``5>,``%`3<("]"``PU>4``%/C<("]""`0G^4$`*#A!""@XP$0C^">\__K
M``!0XW"`O1@%`*#A<$"]Z!GY_^I8`@``"#"?Y0,PC^``,)/E%O/_ZMQ(`0#P
M1RWI3&"?Y4Q0G^4&8(_@!5"/X`5@1N``<*#A`8"@X0*0H.'3\O_K1F&PX?"'
MO0@`0*#C`4"$X@0PE>0)(*#A"!"@X0<`H.$S_R_A!`!6X??__QKPA[WH1$8!
M`#Q&`0`>_R_A"$`MZ0B`O>@!``(`<&5R;'AS:2YC````7U]%3E9?4$%27T-,
M14%.7U\@("`@("`@("`@("`@("``````+@```"XN```E<R\E<P```"]P<F]C
M+W-E;&8O97AE``!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N
M86QS.CI005(Z.D)/3U0`````+W!R;V,O)6DO)7,`97AE`%!!4E]414U0````
M`%!!4E]04D]'3D%-10`````Z````)7,E<R5S```O````4$523#5,24(`````
M4$523$Q)0@!015),-4]05`````!015),24\``%!!4E])3DE424%,25I%1`!0
M05)?4U!!5TY%1`!005)?0TQ%04X```!005)?1$5"54<```!005)?0T%#2$4`
M``!005)?1TQ/0D%,7T1%0E5'`````%!!4E]'3$]"04Q?5$U01$E2````4$%2
M7U1-4$1)4@``4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`````
M4$%27T-,14%./0``,0```$Q$7TQ)0E)!4EE?4$%42`!365-414T``"4P,G@`
M````)7,E<R5S)7,`````<&%R+0`````E<SH@8W)E871I;VX@;V8@<')I=F%T
M92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*```E<SH@<')I
M=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E
M(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*``!0051(`````'!A<FP`
M````+G!A<@`````E<R5S8V%C:&4M)7,E<P``)7,E<W1E;7`M)74E<P```"5S
M)7-T96UP+25U+25U)7,`````05)'5@`````8````<&5R;``````P````4$%2
M.CI086-K97(Z.E9%4E-)3TX`````,2XP-#<```!5;F%B;&4@=&\@8W)E871E
M(&-A8VAE(&1I<F5C=&]R>0`````E<SH@8W)E871I;VX@;V8@<')I=F%T92!C
M86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*`````"UE
M```M+0``55-%4@````!54T523D%-10````!414U01$E2`%1-4``O=&UP````
M`&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII
M9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?
M7W!A<E]P;#L*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92D[
M"D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI4
M96UP.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P
M96,["FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R
M7W1E;7`I.PIO=71S*'%Q>U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B
M?2D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I
M<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF
M("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP
M(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)
M4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8
M(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["G!R:6YT("1T;7`@(B,A+V)I
M;B]S:`IX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P
M87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K
M"F9I"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<B("X@)'1M
M<"T^9FEL96YA;64@+B`B)PHB.PIC:&UO9"`P-S`P+"1T;7`M/F9I;&5N86UE
M.PIM>2`D8VUD(#T@)'1M<"T^9FEL96YA;64@+B`G(#XO9&5V+VYU;&P@,CXF
M,2`F)SL*8VQO<V4@)'1M<#L*<WES=&5M*"1C;60I.PIO=71S*'%Q*%-P87=N
M960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@*0HN
M("1T;7`M/F9I;&5N86UE*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!
M4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PIE
M=F%L('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D<75I970@/2`A)$5.5GM005)?
M1$5"54=].PIM>2`E0V]N9FEG(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^
M("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@("`@/3X@*"1>3R`]
M?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E
M;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G
M*2P**3L*7W-E=%]P<F]G;F%M92@I.PI?<V5T7W!A<E]T96UP*"D["FUY("@D
M<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI["FQO8V%L("1324=[7U]705).7U]]
M(#T@<W5B('M].PIO<&5N(%]&2"P@)SPG+"`D<')O9VYA;64@;W(@;&%S=#L*
M8FEN;6]D92A?1D@I.PIM>2`D8G5F.PIM>2`D<VEZ92`]("US("1P<F]G;F%M
M93L*;7D@)&]F9G-E="`](#4Q,CL*;7D@)&ED>"`]("TQ.PIW:&EL92`H,2D*
M>PHD;V9F<V5T(#T@)'-I>F4@:68@)&]F9G-E="`^("1S:7IE.PIS965K(%]&
M2"P@+21O9F9S970L(#(@;W(@9&EE('%Q6W-E96L@9F%I;&5D(&]N("(D<')O
M9VYA;64B.B`D(5T["FUY("1N<F5A9"`](')E860@7T9(+"`D8G5F+"`D;V9F
M<V5T.PID:64@<7%;<F5A9"!F86EL960@;VX@(B1P<F]G;F%M92(Z("0A72!U
M;FQE<W,@)&YR96%D(#T]("1O9F9S970["B1I9'@@/2!R:6YD97@H)&)U9BP@
M(EQN4$%2+G!M7&XB*3L*;&%S="!I9B`D:61X(#X](#`@?'P@)&]F9G-E="`]
M/2`D<VEZ92!\?"`D;V9F<V5T(#X@,3(X("H@,3`R-#L*)&]F9G-E="`J/2`R
M.PI]"FQA<W0@=6YL97-S("1I9'@@/CT@,#L*)&]F9G-E="`M/2`D:61X("T@
M-#L*<V5E:R!?1D@L("TD;V9F<V5T+"`R.PIR96%D(%]&2"P@)&)U9BP@-#L*
M<V5E:R!?1D@L("TD;V9F<V5T("T@=6YP86-K*").(BP@)&)U9BDL(#(["G)E
M860@7T9(+"`D8G5F+"`T.PHD9&%T85]P;W,@/2`H=&5L;"!?1D@I("T@-#L*
M;7D@)7)E<75I<F5?;&ES=#L*=VAI;&4@*"1B=68@97$@(D9)3$4B*2!["G)E
M860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@
M)&)U9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U=',H<7$H56YP86-K:6YG
M(&9I;&4@(B1F=6QL;F%M92(N+BXI*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE
M(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B
M87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ
M*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C
M:R@B3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O
M7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F
M:6QE*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L
M;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&
M=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-I9B`H("1F
M=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@)$5.5GM005)?
M5$5-4'T@*2!["FUY("1F:6QE;F%M92`](%]T96UP9FEL92@B)&)A<V5N86UE
M)&5X="(L("1B=68L(#`W-34I.PIO=71S*")32$Q)0CH@)&9I;&5N86UE7&XB
M*3L*?0IE;'-E('L*)')E<75I<F5?;&ES='LD9G5L;&YA;65](#T*)%!!4CHZ
M2&5A=GDZ.DUO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F
M+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["GT*<F5A9"!?
M1D@L("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L
M("1M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO
M9'5L93L*;7D@)&9I;&5N86UE(#T@9&5L971E("1R97%U:7)E7VQI<W1[)&UO
M9'5L97T@?'P@9&\@>PIM>2`D:V5Y.PIF;W)E86-H("AK97ES("5R97%U:7)E
M7VQI<W0I('L*;F5X="!U;FQE<W,@+UQ1)&UO9'5L95Q%)"\["B1K97D@/2`D
M7SL@;&%S=#L*?0ID96QE=&4@)')E<75I<F5?;&ES='LD:V5Y?2!I9B!D969I
M;F5D*"1K97DI.PI](&]R(')E='5R;CL*)$E.0WLD;6]D=6QE?2`]("(O;&]A
M9&5R+R1F:6QE;F%M92\D;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,14%.?2!A
M;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I
M;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PIP<FEN
M="`D9F@@)&9I;&5N86UE+3Y[8G5F?3L*<V5E:R@D9F@L(#`L(#`I.PIR971U
M<FX@)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H(B1F
M:6QE;F%M92T^>V-R8WTN<&TB+"`D9FEL96YA;64M/GMB=69]*3L*;W!E;B!M
M>2`D9F@L("<\)RP@)&9I;&5N86UE(&]R(&1I92`B8V%N)W0@<F5A9"`D9FEL
M96YA;64Z("0A(CL*8FEN;6]D92@D9F@I.PIR971U<FX@)&9H.PI]"F1I92`B
M0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;FYO="!F:6YD("1M;V1U;&4A7&XB
M.PI]+"!`24Y#*3L*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE
M879Y.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(
M96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E
M($E/.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E
M<F5Q=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O
M<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O
M7"YP;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D
M9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN
M<&PD+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*
M;&%S="!U;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P-"(["B1S=&%R=%]P;W,@
M/2`H=&5L;"!?1D@I("T@-#L*?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D
M8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*9&5L971E("1%3E9[4$%2
M7T%04%]2155317T[(",@<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R
M:71Y('!R;V)L96TI"B1Q=6EE="`](#`@=6YL97-S("1%3E9[4$%27T1%0E5'
M?3L*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T
M:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI
M8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@
M("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!
M4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?
M05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P
M87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2![
M"B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA
M<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*
M96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D
M,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D
M,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*
M)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD
M;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$[
M"GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@
M;W(@9&EE(")86%@Z($-A;FYO="!O<&5N(&QO9SH@)"$B.PI]"F5L<VEF("@D
M,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD[
M"FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG
M4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[
M(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I
M<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`
M24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)
M3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)'!A<B`]('-H
M:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PI!<F-H
M:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@Q,C@J,3`R-"D["F]P96X@;7D@)&9H
M+"`G/"<L("1P87(@;W(@9&EE(")#86YN;W0@9FEN9"`G)'!A<B<Z("0A(CL*
M8FEN;6]D92@D9F@I.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@
M07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE
M*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE
M(")296%D("<D<&%R)R!E<G)O<CH@)"$B.PI]"FUY("5E;G8@/2!D;R!["FEF
M("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM
M;"<I*2!["B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S+UY<
M4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT[
M"FQO8V%L("0O(#T@7#0["FEF("AD969I;F5D("1P87(I('L*;W!E;B!005(L
M("<\)RP@)'!A<B!O<B!D:64@(B0A.B`D<&%R(CL*8FEN;6]D92A005(I.PID
M:64@(B1P87(@:7,@;F]T(&$@4$%2(&9I;&4B('5N;&5S<R`\4$%2/B!E<2`B
M4$M<,#`S7#`P-"(["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/
M.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ
M1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L
M"BD@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["B0O(#T@*&1E9FEN960@)&1A
M=&%?<&]S*2`_(%PD9&%T85]P;W,@.B!U;F1E9CL*<V5E:R!?1D@L(#`L(#`[
M"FUY("1L;V%D97(@/2!S8V%L87(@/%]&2#X["FEF("@A)$5.5GM005)?5D52
M0D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U
M:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T
M<FEP+3YN97<M/F%P<&QY*%PD;&]A9&5R+"`D,"D*?0IF;W)E86-H(&UY("1K
M97D@*'-O<G0@:V5Y<R`E96YV*2!["FUY("1V86P@/2`D96YV>R1K97E](&]R
M(&YE>'0["B1V86P@/2!E=F%L("1V86P@:68@)'9A;"`]?B`O7ELG(ETO.PIM
M>2`D;6%G:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?7R(["FUY
M("1S970@/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A;"(["B1L;V%D97(@
M/7X@<WLD;6%G:6,H("LI?7L*)&UA9VEC("X@)'-E="`N("@G("<@>"`H;&5N
M9W1H*"0Q*2`M(&QE;F=T:"@D<V5T*2DI"GUE9SL*?0HD9F@M/G!R:6YT*"1L
M;V%D97(I.PHD+R`]('5N9&5F.PII9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!
M4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI
M=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P('L@
M(2]"4T1004XO('T*9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(**"1?
M(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O
M;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIM>2`E9FEL97,[
M"B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE
M8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF
M:6=[;&EB7V5X='T["FUY("5W<FET=&5N.PIF;W)E86-H("AS;W)T(&ME>7,@
M)69I;&5S*2!["FUY("@D;F%M92P@)&9I;&4I.PIF;W)E86-H(&UY("1D:7(@
M*$!I;F,I('L*:68@*"1N86UE(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD
M7WTI('L*)&9I;&4@/2`D7SL*;&%S=#L*?0IE;'-I9B`H+UXH7%$D9&ER7$5<
M+R@N*EM>0V-=*2E<6B]I*2!["B@D9FEL92P@)&YA;64I(#T@*"0Q+"`D,BD[
M"FQA<W0["GT*96QS:68@*&TA7B]L;V%D97(O6UXO72LO*"XJ6UY#8UTI7%HA
M*2!["FEF("AM>2`D<F5F(#T@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R0Q
M?2D@>PHH)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*96QS
M:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D
M,2(L("0Q*3L*;&%S=#L*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M
M92!A;F0@;F]T("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H)&9I
M;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+SL*;W5T<R@@:F]I
M;B`B(BP*<7$H4&%C:VEN9R`B*2P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE
M?2`Z("1F:6QE+`IQ<2@B+BXN*0HI.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D
M9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92!["F]P
M96X@1DE,12P@)SPG+"`D9FEL92!O<B!D:64@(D-A;B=T(&]P96X@)&9I;&4Z
M("0A(CL*8FEN;6]D92A&24Q%*3L*)&-O;G1E;G0@/2`\1DE,13X["F-L;W-E
M($9)3$4["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&-O
M;G1E;G0L("1F:6QE*0II9B`A)$5.5GM005)?5D520D%424U](&%N9"`D;F%M
M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!4CHZ1FEL=&5R.CI0871C:$-O
M;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92P@)&YA;64I.PI]
M"F]U=',H<7$H5W)I='1E;B!A<R`B)&YA;64B*2D["B1F:"T^<')I;G0H(D9)
M3$4B*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI
M*3L*)&9H+3YP<FEN="AS<')I;G1F*`HB)3`X>"\E<R(L($%R8VAI=F4Z.EII
M<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64**2D["B1F:"T^<')I
M;G0H<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI*3L*)&9H+3YP<FEN="@D
M8V]N=&5N="D["GT*?0HD>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I(&EF
M("1Z:7`["B1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`T
M,#L*:68@*"$D8V%C:&5?;F%M92!A;F0@;7D@)&UT:6UE(#T@*'-T870H)&]U
M="DI6SE=*2!["FUY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(
M03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"GQ\(&5V86P@>R!R97%U:7)E($1I
M9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0I\?"!E=F%L('L@<F5Q
M=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PIM>2`D<VAA
M7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@
M,#L*:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N
M(&5Q("<U+C,Y)RD@>PHD8W1X+3YA9&1F:6QE*"1O=70L(")B(BD@:68@*"1C
M='@I.PI]"F5L<V4@>PII9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)&]U
M="(I*2!["F)I;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL92@D9F@I.PIC;&]S
M92@D9F@I.PI]"GT*)&-A8VAE7VYA;64@/2`D8W1X(#\@)&-T>"T^:&5X9&EG
M97-T(#H@)&UT:6UE.PI]"B1C86-H95]N86UE("X](")<,"(@>"`H-#$@+2!L
M96YG=&@@)&-A8VAE7VYA;64I.PHD8V%C:&5?;F%M92`N/2`B0T%#2$4B.PHD
M9F@M/G!R:6YT*"1C86-H95]N86UE*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@
M)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I*2D["B1F:"T^<')I;G0H(EQN
M4$%2+G!M7&XB*3L*)&9H+3YC;&]S93L*8VAM;V0@,#<U-2P@)&]U=#L*97AI
M=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P
M<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN
M86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H
M:79E.CI::7`["GT*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PIM>2`D
M9F@@/2!)3SHZ1FEL92T^;F5W.PHD9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@
M)W(G*2!O<B!D:64@(B0A.B`D0"(["B1Z:7`M/G)E861&<F]M1FEL94AA;F1L
M92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I(&]R
M(&1I92`B)"$Z("1`(CL*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!
M4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["B1Q=6EE="`]("$D14Y6
M>U!!4E]$14)51WT["F]U=',H<7$H7"1%3E9[4$%27U1%35!](#T@(B1%3E9[
M4$%27U1%35!](BDI.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C
M('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D;65M
M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI<T1I
M<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64[
M"FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_
M.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PHH/SHD0V]N9FEG.CI#;VYF
M:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M
M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D
M14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S=%]N
M86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2![
M"F]U=',H<7$H4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR
M96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B*2D["GT@96QS92!["F]U=',H
M<7$H17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92(I
M*3L*)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I.PIC
M:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]"GT*
M?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID:64@
M/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@
M6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN
M<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%3E9[
M4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I
M.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR97%U:7)E
M($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@
M/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D[
M"G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P871H
M*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*
M?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E<75I<F4@
M1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T<FEC=#L*
M<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E($-A<G`[
M"G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E<75I<F4@
M17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U:7)E($9C
M;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E8SL*
M<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@24\Z
M.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S<SHZ
M6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@4$%2.PIR97%U
M:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!
M4CHZ1FEL=&5R.CI0;V13=')I<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T
M8VA#;VYT96YT.PIR97%U:7)E(&%T=')I8G5T97,["F5V86P@>R!R97%U:7)E
M($-W9"!].PIE=F%L('L@<F5Q=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER
M92!38V%L87(Z.E5T:6P@?3L*979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ
M:7`Z.D)U<G-T('T["F5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#
M87!T=7)E('T["F5V86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L
M24\Z.G-C86QA<B!].PIE=F%L('L@<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S
M971?<&%R7W1E;7`@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@
M)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR
M971U<FX["GT*9F]R96%C:"!M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W
M*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI+`IQ=R@@
M0SI<7%1%35`@+W1M<"`N("D**2!["FYE>'0@=6YL97-S(&1E9FEN960@)'!A
M=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM
M>2`D<'=U:60["F5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E
M9FEN960@)#X[?3L*:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I
M('L*)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["GT*96QS:68@*&1E
M9FEN960@)'!W=6ED*2!["B1U<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E('L*
M)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G
M4UE35$5-)SL*?0HD=7-E<FYA;64@/7X@<R]<5R]?+V<["FUY("1S=&UP9&ER
M(#T@(B1P871H)$-O;F9I9WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U
M<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PII9B`H(21%3E9[4$%2
M7T-,14%.?2!A;F0@;7D@)&UT:6UE(#T@*'-T870H)'!R;V=N86UE*2E;.5TI
M('L*;W!E;B`H;7D@)&9H+"`B/"(N("1P<F]G;F%M92D["G-E96L@)&9H+"`M
M,3@L(#(["G-Y<W)E860@)&9H+"!M>2`D8G5F+"`V.PII9B`H)&)U9B!E<2`B
M7#!#04-(12(I('L*<V5E:R`D9F@L("TU."P@,CL*<WES<F5A9"`D9F@L("1B
M=68L(#0Q.PHD8G5F(#U^(',O7#`O+V<["B1S=&UP9&ER("X]("(D0V]N9FEG
M>U]D96QI;7UC86-H92TB("X@)&)U9CL*?0IE;'-E('L*;7D@)&-T>"`](&5V
M86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I
M('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(
M03$M/FYE=R!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$:6=E
M<W0Z.DU$-2T^;F5W('T["FUY("1S:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG
M97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PII9B`H)'-H85]V97)S:6]N(&5Q
M("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2!["B1C='@M/F%D
M9&9I;&4H)'!R;V=N86UE+"`B8B(I(&EF("@D8W1X*3L*?0IE;'-E('L*:68@
M*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1P<F]G;F%M92(I*2!["F)I;FUO
M9&4H)&9H*3L*)&-T>"T^861D9FEL92@D9F@I.PIC;&]S92@D9F@I.PI]"GT*
M)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`H("1C='@@
M/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64@*3L*?0IC;&]S92@D9F@I.PI]
M"F5L<V4@>PHD14Y6>U!!4E]#3$5!3GT@/2`Q.PHD<W1M<&1I<B`N/2`B)$-O
M;F9I9WM?9&5L:6U]=&5M<"TD)"(["GT*)$5.5GM005)?5$5-4'T@/2`D<W1M
M<&1I<CL*;6MD:7(@)'-T;7!D:7(L(#`W-34["FQA<W0["GT*)'!A<E]T96UP
M(#T@)#$@:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^
M("\H+BLI+SL*?0IS=6(@7W1E;7!F:6QE('L*;7D@*"1N86UE+"`D8V]N=&5N
M=',L("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N
M86UE(CL*=6YL97-S("@M92`D9G5L;&YA;64I('L*;7D@)'1E;7!N86UE(#T@
M(B1F=6QL;F%M92XD)"(["F]P96X@;7D@)&9H+"`G/B<L("1T96UP;F%M92!O
M<B!D:64@(F-A;B=T('=R:71E("1T96UP;F%M93H@)"$B.PIB:6YM;V1E("1F
M:#L*<')I;G0@)&9H("1C;VYT96YT<SL*8VQO<V4@)&9H.PIC:&UO9"`D;6]D
M92P@)'1E;7!N86UE(&EF(&1E9FEN960@)&UO9&4["G)E;F%M92@D=&5M<&YA
M;64L("1F=6QL;F%M92D@;W(@=6YL:6YK*"1T96UP;F%M92D["GT*<F5T=7)N
M("1F=6QL;F%M93L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D
M("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^
M("\H+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P
M.PII9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.
M5GM005)?5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G
M;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I
M.PI]"FEF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M
M92P@)$-O;F9I9WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY("1F:"P@
M)SPG+"`D<')O9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II9B`H+7,@
M(B1P<F]G;F%M921#;VYF:6=[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D0V]N
M9FEG>U]E>&5].PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET
M("]<421#;VYF:6=[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@
M:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%2
M7U1%35!].PHD9&ER(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<120O+SL**"@D
M<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF
M:6=[7V5X97TB*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD
M<')O9VYA;64D0V]N9FEG>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1#
M;VYF:6=[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I<B1#
M;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M
M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF
M("AI;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P*2!["B1P
M<F]G;F%M92`]("(N)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D
M<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*
M.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I
M(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN
M7"X_7%$D0V]N9FEG>U]D96QI;7U<12DO)'!W9"1#;VYF:6=[7V1E;&EM?2\[
M"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I
M;FET7V5N=B!["FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I
M('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R
M.PI]"F9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!0
M4D]'3D%-12!!4D=#($%21U9?,"`I("D@>PID96QE=&4@)$5.5GLG4$%27R<N
M)%]].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*
M)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG4$%27T=,3T)!3%\G+B1??2!I9B!E
M>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*?0IM>2`D<&%R7V-L96%N
M(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@(CL*:68@*"1%
M3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#3$5!3GT["GT*96QS
M:68@*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,7T-,14%.?2D@>PIM>2`D=F%L
M=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L96YG=&@H(D-,14%.(BDI
M.PHD14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@/7X@+UY005)?0TQ%
M04X]*%Q3*RDO.PI]"GT*<W5B(&]U=',@>PIR971U<FX@:68@)'%U:65T.PII
M9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B(["GT*96QS92!["G!R
M:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E<75I<F4@0V]N9FEG
M.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I
M9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@
M<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A
M8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z
M.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@<7$H<&%R
M+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S
M=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&XI"G5N;&5S<R`M92`D<')O9VYA;64[
M"F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?
M15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI].PHD.CI?7T524D]2
M(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@
M/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D
M.CI?7T524D]2.PHQ.PI?7T5.1%]?"@`@D?]_`0``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````W!D``'09```!`````0````$```#+`0```0```-8!```!````X`$```$`
M```O`@```0```(@#```!````J`,```P```"H$@``#0```)1'```9````A(T!
M`!L````$````&@```(B-`0`<````!````/7^_V^L`0``!0```'@)```&````
MF`(```H````,!0``"P```!`````5``````````,```"TC@$``@`````"```4
M````$0```!<```"H$```$0```,`/```2````Z````!,````(````'@````@`
M``#[__]O`0``"/[__V]@#P``____;P,```#P__]OA`X``/K__V\0````````
M`````````````````````````````````````````````````(R-`0``````
M`````+02``"T$@``M!(``+02``"T$@``M!(``+02``"T$@``M!(``+02``"T
M$@``M!(``+02``"T$@``M!(``+02``"T$@``M!(``+02``"T$@``M!(``+02
M``"T$@``M!(``+02``"T$@``M!(``+02``"T$@``M!(``+02``"T$@``M!(`
M`+02``"T$@``M!(``+02``"T$@``M!(``+02``"T$@``M!(``+02``"T$@``
MM!(``+02``"T$@``M!(``+02``"T$@``M!(``+02``"T$@``M!(``+02``"T
M$@``M!(``+02``"T$@``M!(``+02``"T$@``M!(``+02``"01P``````````
M````````````````````````````````````````,$<```````#(%0``````
M``````````````````20`0#_____"$L``-!'````````\$@``/1(``#\2@``
M.$@```1+````````Z$H``/!*````````$$L``$=#0SH@*$1E8FEA;B`X+C(N
M,"TY*2`X+C(N,`!'0T,Z("A$96)I86X@-RXS+C`M,CDI(#<N,RXP`$$J````
M865A8FD``2`````%-51%``8$"`$)`1($$P$4`14!%P,8`1D!&@(`+G-H<W1R
M=&%B`"YI;G1E<G``+FYO=&4N04))+71A9P`N;F]T92YG;G4N8G5I;&0M:60`
M+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV
M97)S:6]N7W(`+G)E;"YD>6X`+G)E;"YP;'0`+FEN:70`+G1E>'0`+F9I;FD`
M+G)O9&%T80`N05)-+F5X:61X`"YE:%]F<F%M90`N:6YI=%]A<G)A>0`N9FEN
M:5]A<G)A>0`N9'EN86UI8P`N9V]T`"YD871A`"YB<W,`+F-O;6UE;G0`+D%2
M32YA='1R:6)U=&5S````````````````````````````````````````````
M```````````````+`````0````(```!4`0``5`$``!,```````````````$`
M````````$P````<````"````:`$``&@!```@```````````````$````````
M`"$````'`````@```(@!``"(`0``)```````````````!``````````T````
M]O__;P(```"L`0``K`$``.P````%``````````0````$````/@````L````"
M````F`(``)@"``#@!@``!@````,````$````$````$8````#`````@```'@)
M``!X"0``#`4``````````````0````````!.````____;P(```"$#@``A`X`
M`-P````%``````````(````"````6P```/[__V\"````8`\``&`/``!@````
M!@````,````$`````````&H````)`````@```,`/``#`#P``Z`````4`````
M````!`````@```!S````"0```$(```"H$```J!`````"```%````%0````0`
M```(````?`````$````&````J!(``*@2```,```````````````$````````
M`'<````!````!@```+02``"T$@``%`,`````````````!`````0```""````
M`0````8```#(%0``R!4``,PQ``````````````@`````````B`````$````&
M````E$<``)1'```(```````````````$`````````(X````!`````@```)Q'
M``"<1P``J#\`````````````!`````````"6`````0``<((```!$AP``1(<`
M``@````-``````````0`````````H0````$````"````3(<``$R'```$````
M```````````$`````````*L````.`````P```(2-`0"$C0``!```````````
M````!`````0```"W````#P````,```"(C0$`B(T```0```````````````0`
M```$````PP````8````#````C(T!`(R-```H`0``!@`````````$````"```
M`,P````!`````P```+2.`0"TC@``3`$`````````````!`````0```#1````
M`0````,`````D`$``)```$````````````````0`````````UP````@````#
M````0)`!`$"0```8$``````````````$`````````-P````!````,```````
M``!`D```.0```````````````0````$```#E`````P``<```````````>9``
M`"L```````````````$``````````0````,``````````````*20``#U````
0```````````!````````````
